# Example projects

Project URL: [Starter project](https://github.com/Almas-Ali/fronty/tree/master/examples/starter%20project)

![Starter Project](https://raw.githubusercontent.com/Almas-Ali/fronty/master/examples/starter%20project/screenshot_1.png "Starter Project")


Project URL: [Bootstrap Integration](https://github.com/Almas-Ali/fronty/tree/master/examples/Bootstrap%20integration)

![Bootstrap Integration](https://raw.githubusercontent.com/Almas-Ali/fronty/master/examples/Bootstrap%20integration/screenshot_1.png "Bootstrap Integration")


Project URL: [Custom CSS Project](https://github.com/Almas-Ali/fronty/tree/master/examples/Custom%20CSS%20Project)

![Custom CSS Project](https://raw.githubusercontent.com/Almas-Ali/fronty/master/examples/Custom%20CSS%20Project/screenshot_1.png "Custom CSS Project")

![Custom CSS Project](https://raw.githubusercontent.com/Almas-Ali/fronty/master/examples/Custom%20CSS%20Project/screenshot_2.png "Custom CSS Project")


## How to run the example projects? 

You can easily run the example projects by cloning the Fronty repository and running the following commands in your terminal.

1. Clone the Fronty repository.
1. Go to the **examples/starter project** directory. <br> 
```bash
cd fronty/examples/starter\ project
```

1. Run the following command in your terminal.
```bash
python app.py
```

1. Open your browser and go to **http://localhost:5000**
![Starter Project](https://raw.githubusercontent.com/Almas-Ali/fronty/master/examples/starter%20project/screenshot_1.png "Starter Project")

1. You can also run the other example projects by going to their directories and running the same command.

1. **Note:** You have to install a backend server to run the project. Fronty does not provide a backend server. You can use any backend server you want. For example, you can use Flask. You can also use Fronty with Django. But you have to install Django first. For simplicity, we have used Flask in the example projects. We are woring on a backend server for Fronty. It will be available soon.

